==> buildz-0.6.39.tar.gz: buildz-0.6.39/buildz/logz.py <==
#


from . import xf, ioc, fz
from .base import Base
from .ioc import wrap
#from .tools import *
import time, sys, threading
ns = wrap.ns("buildz.logz")
@ns.obj(id="baseLog")
@ns.obj_args("ref, buildz.logz.shows, null", "ref, buildz.logz.tag, null", "ref, buildz.logz.base, null")
class Log(Base):
    def call(self, _tag):
        return self.tag(_tag)
    def tag(self, _tag):
        if type(_tag) != str:
            try:
                if not hasattr(_tag, "__name__"):
                    _tag = _tag.__class__
                _tag = _tag.__module__+"."+_tag.__name__
            except:
                _tag = str(_tag)
        log = Log(self.shows, _tag, self)
        return log
    def get_tag(self):
        return self._tag
    def init(self, shows = None, tag= None, base = None, lock = False):
        if shows is None:
            shows = ["info", "debug", "warn", "error"]
        self.shows=shows
        self._tag = tag
        self.base = base
        if lock:
            self.lock = threading.Lock()
        else:
            self.lock = None
    def log(self, level, tag, *args):
        if self.lock is not None:
            with self.lock:
                return self.do_log(level, tag, *args)
        return self.do_log(level, tag, *args)
    def xlog(self, level, *args):
        if level not in self.shows:
            return
        self.log(level, self.tag, *args)
    def do_log(self, level, tag, *args):
        if self.base is not None:
            return self.base.log(level, tag, *args)
        raise Exception("unimpl")
    def info(self, *args):
        if "info" not in self.shows:
            return
        self.log("info", self._tag, *args)
    def warn(self, *args):
        if "warn" not in self.shows:
            return
        self.log("warn", self._tag, *args)
    def debug(self, *args):
        if "debug" not in self.shows:
            return
        self.log("debug", self._tag, *args)
    def error(self, *args):
        if "error" not in self.shows:
            return
        self.log("error", self._tag, *args)

pass
def replaces(s, *args):
    for i in range(0,len(args),2):
        k,v = args[i],args[i+1]
        s = s.replace(k,v)
    return s

pass
def mstr(s):
    if s is None or len(s)==0:
        return s
    return s[:1].upper()+s[1:].lower()
@ns.obj(id="formatLog")
@ns.obj_args("ref, buildz.logz.shows, null", "ref, buildz.logz.tag, null", "ref, buildz.logz.format, null")
class FormatLog(Log):
    def init(self, shows =None, tag=None, format=None, lock = False):
        if format is None:
            format = "[{LEVEL}] %Y-%m-%d %H:%M:%S {tag} {msg}\n"
        self.format=format
        super().init(shows, tag, lock)
    def output(self, msg):
        raise Exception("impl")
    def do_log(self, level, tag, *args):
        m_level = level.lower()
        u_level = level.upper()
        x_level = mstr(level)
        args = [str(k) for k in args]
        msg = " ".join(args)
        if tag is None:
            tag = "base"
        rst = time.strftime(self.format, time.localtime(time.time()))
        msg = replaces(rst, "{Level}", x_level, "{level}", m_level, "{LEVEL}", u_level, "{tag}", tag, "{msg}", msg)
        self.output(msg)
class FpLog(FormatLog):
    def init(self, fp = None,shows =None, tag=None, format=None, lock = False):
        super().init(shows, tag, format, lock)
        self.fp = fp
    def output(self, msg):
        #sys.stdout.write(msg)
        if self.fp is not None:
            fp = time.strftime(self.fp)
            fz.makefdir(fp)
            fz.write(msg.encode("utf-8"), fp, 'ab')

pass
class StdLog(FormatLog):
    def output(self, msg):
        sys.stdout.write(msg)

pass
#wrap.decorator.add_datas()
wrap.decorator.add_datas("[logs.list, refs], buildz\.logz\.item,", ns = "buildz.logz")
@ns.obj(id="logs")
@ns.obj_args("ref, logs.list, []", "ref, buildz.logz.shows,null", "ref, buildz.logz.tag, null")
class Logs(Log):
    def init(self, logs, shows = None, tag= None, lock = False):
        super().init(shows, tag, lock=lock)
        self.logs = logs
    def do_log(self, level, tag, *args):
        for _log in self.logs:
            _log.log(level, tag, *args)

pass

def build(obj=None, shows=None, tag=None, format=None):
    if obj is None:
        return StdLog(shows, tag, format)
    return obj

pass
make=build

==> buildz-0.6.43.tar.gz: buildz-0.6.43/buildz/logz.py <==
#


from . import xf, ioc, fz
from .base import Base
from .ioc import wrap
#from .tools import *
import time, sys, threading
ns = wrap.ns("buildz.logz")
@ns.obj(id="baseLog")
@ns.obj_args("ref, buildz.logz.shows, null", "ref, buildz.logz.tag, null", "ref, buildz.logz.base, null")
class Log(Base):
    def call(self, _tag):
        return self.tag(_tag)
    def tag(self, _tag):
        if type(_tag) != str:
            try:
                if not hasattr(_tag, "__name__"):
                    _tag = _tag.__class__
                _tag = _tag.__module__+"."+_tag.__name__
            except:
                _tag = str(_tag)
        log = Log(self.shows, _tag, self)
        return log
    def get_tag(self):
        return self._tag
    def init(self, shows = None, tag= None, base = None, lock = False):
        if shows is None:
            shows = ["info", "debug", "warn", "error"]
        self.shows=shows
        self._tag = tag
        self.base = base
        if lock:
            self.lock = threading.Lock()
        else:
            self.lock = None
    def log(self, level, tag, *args):
        if self.lock is not None:
            with self.lock:
                return self.do_log(level, tag, *args)
        return self.do_log(level, tag, *args)
    def xlog(self, level, *args):
        if level not in self.shows:
            return
        self.log(level, self.tag, *args)
    def do_log(self, level, tag, *args):
        if self.base is not None:
            return self.base.log(level, tag, *args)
        raise Exception("unimpl")
    def info(self, *args):
        if "info" not in self.shows:
            return
        self.log("info", self._tag, *args)
    def warn(self, *args):
        if "warn" not in self.shows:
            return
        self.log("warn", self._tag, *args)
    def debug(self, *args):
        if "debug" not in self.shows:
            return
        self.log("debug", self._tag, *args)
    def error(self, *args):
        if "error" not in self.shows:
            return
        self.log("error", self._tag, *args)

pass
def replaces(s, *args):
    for i in range(0,len(args),2):
        k,v = args[i],args[i+1]
        s = s.replace(k,v)
    return s

pass
def mstr(s):
    if s is None or len(s)==0:
        return s
    return s[:1].upper()+s[1:].lower()
@ns.obj(id="formatLog")
@ns.obj_args("ref, buildz.logz.shows, null", "ref, buildz.logz.tag, null", "ref, buildz.logz.format, null")
class FormatLog(Log):
    def init(self, shows =None, tag=None, format=None, lock = False):
        if format is None:
            format = "[{LEVEL}] %Y-%m-%d %H:%M:%S {tag} {msg}\n"
        self.format=format
        super().init(shows, tag, lock)
    def output(self, msg):
        raise Exception("impl")
    def do_log(self, level, tag, *args):
        m_level = level.lower()
        u_level = level.upper()
        x_level = mstr(level)
        args = [str(k) for k in args]
        msg = " ".join(args)
        if tag is None:
            tag = "base"
        rst = time.strftime(self.format, time.localtime(time.time()))
        msg = replaces(rst, "{Level}", x_level, "{level}", m_level, "{LEVEL}", u_level, "{tag}", tag, "{msg}", msg)
        self.output(msg)
class FpLog(FormatLog):
    def init(self, fp = None,shows =None, tag=None, format=None, lock = False):
        super().init(shows, tag, format, lock)
        self.fp = fp
    def output(self, msg):
        #sys.stdout.write(msg)
        if self.fp is not None:
            fp = time.strftime(self.fp)
            fz.makefdir(fp)
            fz.write(msg.encode("utf-8"), fp, 'ab')

pass
class StdLog(FormatLog):
    def output(self, msg):
        sys.stdout.write(msg)

pass
#wrap.decorator.add_datas()
wrap.ns.add_datas("[logs.list, refs], buildz\.logz\.item,", ns = "buildz.logz")
@ns.obj(id="logs")
@ns.obj_args("ref, logs.list, []", "ref, buildz.logz.shows,null", "ref, buildz.logz.tag, null")
class Logs(Log):
    def init(self, logs, shows = None, tag= None, lock = False):
        super().init(shows, tag, lock=lock)
        self.logs = logs
    def do_log(self, level, tag, *args):
        for _log in self.logs:
            _log.log(level, tag, *args)

pass

def build(obj=None, shows=None, tag=None, format=None):
    if obj is None:
        return StdLog(shows, tag, format)
    return obj

pass
make=build
